function oscplotscreen(OscRecord,shouldUseOscZero=false)
  
# oscplotscreen(OscRecord, shouldUseOscZero)
#
# Plots the data contained in the structure OscRecord in a form possibly close 
# to that on the oscilloscope's screen when the data were saved.
#
# If the optional parameter shouldUseOscZero is true, zero level shift as 
# on the oscilloscope's screen is applied (resulting in it being shifted with 
# respect to the Y-axis grid displayed). Otherwise, this shift is ignored.

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  figure();
  hold on;
  for iWfm = [1:OscRecord.nWfms]
    Params = OscRecord.Waveforms(iWfm).Params;
    if (shouldUseOscZero)
      yShift = Params.yZero;
    else
      yShift = 0;
    endif
    wfmLabel = cstrcat(Params.label, " / ", num2str(Params.yScale), " ", Params.yUnit);
    if (shouldUseOscZero)
      if yShift >= 0
        wfmLabel = cstrcat(wfmLabel, " + ", num2str(yShift));
      else
        wfmLabel = cstrcat(wfmLabel, " - ", num2str(-yShift));
      endif
    endif
    fmt = strcat(";", wfmLabel, ";");
    plot(OscRecord.Waveforms(iWfm).Values.x, ...
      OscRecord.Waveforms(iWfm).Values.y / Params.yScale + yShift, fmt);
  endfor
  if (shouldUseOscZero)
    ylim([-5 5]);
    hax = gca();
    set(hax, "ytick", [-5:1:5]);
  endif
  grid on;
  xlabel(Params.xUnit);
  
endfunction
