function oscplotxy(OscRecord, wfmX, wfmY)

# oscplotxy(OscRecord, wfmX, wfmY)
#
# Plots the waveform indentified by wfmY against that identified by wfmX (an XY
# graph), as contained in the structure OscRecord.
#
# If wfm* is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
#
# For a description of OscRecord, see oscreadtbs().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  if (!isnumeric(wfmX))
    wfmX = oscwfmidx(OscRecord, wfmX);
  endif
  if (!isnumeric(wfmY))
    wfmY = oscwfmidx(OscRecord, wfmY);
  endif
  
  plot(OscRecord.Waveforms(wfmX).Values.y, OscRecord.Waveforms(wfmY).Values.y, "-+");
  grid on;
  ParamsX = OscRecord.Waveforms(wfmX).Params;
  ParamsY = OscRecord.Waveforms(wfmY).Params;
  xlabel(cstrcat(ParamsX.label, " / ", ParamsX.yUnit));
  ylabel(cstrcat(ParamsY.label, " / ", ParamsY.yUnit));
  
endfunction
