function [axtrj,axpwr]=plot3p_outtrjpwr(OscRecord,idxU,idxI,TrcRecordOutChar=[])
  
# [axtrj, axpwr] = plot3p_outtrjpwr(OscRecord, idxU, idxI, TrcRecordOutChar)
#
# Plots operating point trajectory and power dissipation for a device. The 
# structure OscRecord contains oscilloscope waveforms of device voltage (a 
# waveform with the index idxU) and current (a waveform with the index idxI).
#
# An additional structure TrcRecordOutChar can be provided with static output 
# characteristic data from a curve tracer. This characteristic is then
# plotted in the background of the operating point trajectory.

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  STAT_CHAR_MARG = 0.05;
  
  WfmU = OscRecord.Waveforms(idxU);
  WfmI = OscRecord.Waveforms(idxI);
  figure();
  
  axtrj=subplot(2,1,1);
  hold on;
  if (!isempty(TrcRecordOutChar))
    iIf = trcvaridx(TrcRecordOutChar, "If");
    iUf = trcvaridx(TrcRecordOutChar, "Vf");
    TrcRecordOutChar = trccrop(TrcRecordOutChar, max(WfmI.Values.y)*(1+STAT_CHAR_MARG), ...
      max(WfmU.Values.y)*(1+STAT_CHAR_MARG), 0, 0);
    for iSet = [1:TrcRecordOutChar.nSets]
      plot(TrcRecordOutChar.Sets(iSet).values(:,iUf), TrcRecordOutChar.Sets(iSet).values(:,iIf), ':m');
    endfor
  endif
  oscplotxy(OscRecord, idxU, idxI);
  
  axpwr=subplot(2,1,2);
  WfmP.Values.y = WfmU.Values.y .* WfmI.Values.y;
  WfmP.Params.label = cstrcat(WfmU.Params.label, "*", WfmI.Params.label);
  if (strcmp(WfmU.Params.yUnit, "V") && strcmp(WfmI.Params.yUnit, "A"))
    WfmP.Params.yUnit = "W";
  else
    WfmP.Params.yUnit = cstrcat(WfmU.Params.yUnit, "*", WfmI.Params.yUnit);
  endif
  idxP = (++OscRecord.nWfms);
  OscRecord.Waveforms(idxP) = WfmP;
  oscplotxy(OscRecord, idxU, idxP);
  xlim(axpwr, get(axtrj, "xlim"));
  hold on;
  
endfunction
