function TrcRecord=trccrop(TrcRecord,ifmax,ufmax=Inf,ifmin=-Inf,ufmin=-Inf)
  
# TrcRecord = trccrop(TrcRecord, ifmax, ufmax, ifmin, ufmin)
#
# Crops the range of data contained in the structure TrcRecord. Cropping is 
# performed exactly to the specified bounds, with linear interpolation if necessary.
#
# To not crop data on a given side, pass Inf (for *max) or -Inf (for *min).
#
# Arguments ufmax, ifmin, ufmin are optional, defaulting to Inf (ufmax) or -Inf
# (ifmin, ufmin).
#
# For a description of TrcRecord, see trcreadagi().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology  

  iIf = trcvaridx(TrcRecord,"If");
  iUf = trcvaridx(TrcRecord,"Vf");
  
  nPoints = [];
  for iSet=[1:TrcRecord.nSets]
    
    CurSet = TrcRecord.Sets(iSet);
    for ip = [2:CurSet.nPoints]
      if (CurSet.values(ip,iIf) > ifmax || CurSet.values(ip,iUf) > ufmax ...
        || (CurSet.values(ip,iIf) == ifmax && (ip == CurSet.nPoints || CurSet.values(ip+1,iIf) > ifmax)) ...
        || (CurSet.values(ip,iUf) == ufmax && (ip == CurSet.nPoints || CurSet.values(ip+1,iUf) > ufmax)))
        vals = CurSet.values(1:ip,:);
        if (vals(ip,iUf)-vals(ip-1,iUf) != 0)
          slope = (vals(ip,iIf)-vals(ip-1,iIf)) / (vals(ip,iUf)-vals(ip-1,iUf));
        else
          slope = Inf;
        endif
        if (vals(ip,iIf) > ifmax)
          vals(ip,iIf) = ifmax;
          if (slope != Inf)
            vals(ip,iUf) = vals(ip-1,iUf) + (ifmax-vals(ip-1,iIf)) / slope;
          else
            vals(ip,iUf) = vals(ip-1,iUf);
          endif
        endif
        if (vals(ip,iUf) > ufmax)
          vals(ip,iUf) = ufmax;
          vals(ip,iIf) = vals(ip-1,iIf) + (ufmax-vals(ip-1,iUf)) * slope;
        endif
        TrcRecord.Sets(iSet).values = vals;
        break
      endif
    endfor
    
    CurSet = TrcRecord.Sets(iSet);
    for ip = [size(CurSet.values, 1)-1:-1:1]
      if (CurSet.values(ip,iIf) < ifmin || CurSet.values(ip,iUf) < ufmin ...
        || (CurSet.values(ip,iIf) == ifmin && (ip == 1 || CurSet.values(ip-1,iIf) < ifmin)) ...
        || (CurSet.values(ip,iUf) == ufmin && (ip == 1 || CurSet.values(ip-1,iUf) < ufmin)))
        vals = CurSet.values(ip:end,:);
        if (vals(1,iUf)-vals(2,iUf) != 0)
          slope = (vals(1,iIf)-vals(2,iIf)) / (vals(1,iUf)-vals(2,iUf));
        else
          slope = Inf;
        endif
        if (vals(1,iIf) < ifmin)
          vals(1,iIf) = ifmin;
          if (slope != Inf)
            vals(1,iUf) = vals(2,iUf) + (ifmin-vals(2,iIf)) / slope;
          else
            vals(1,iUf) = vals(2,iUf);
          endif
        endif
        if (vals(1,iUf) < ufmin)
          vals(1,iUf) = ufmin;
          vals(1,iIf) = vals(2,iIf) + (ufmin-vals(2,iUf)) * slope;
        endif
        TrcRecord.Sets(iSet).values = vals;
        break
      endif
    endfor
    
    nPoints(iSet) = size(TrcRecord.Sets(iSet).values, 1);
    TrcRecord.Sets(iSet).nPoints = nPoints(iSet);      
    
  endfor
  
  TrcRecord.nPointsMax = max(nPoints);
  
endfunction
