function TrcRecord=trcreadcsv(csvFileName)
  
# TrcRecord = trcreadcsv(csvFileName)
#
# Reads data from a CSV file containg characteristic data saved with trcwritecsv()
# and places them in a TrcRecord structure.
#
# To read data from an original curve tracer CSV file, use an appropriate
# function dedicated for the specific curve tracer model.
#
# For a description of TrcRecord, see trcreadagi().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology  
  
  [fCsv, msg] = fopen(csvFileName,"r");
  if (fCsv == -1)
    error(["Could not open file: " msg]);
  endif
  TrcRecord = struct();
  
  lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
  nVars = 0;
  iSet = 0;
  for iCol = [1:length(lineSplit)]
    if (!strcmp(lineSplit(iCol), ""))
      if (iSet > 0)
        TrcRecord.Sets(iSet).nVars = nVars;
        nVars = 0;
      endif
      iSet++;
      TrcRecord.Sets(iSet).Params.param = str2double(lineSplit(iCol));
    endif
    nVars++;
  endfor
  TrcRecord.Sets(iSet).nVars = nVars;
  TrcRecord.nSets = iSet;

  lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
  iCol = 1;
  for iSet = [1:TrcRecord.nSets]
    labels = "";
    for iVar = [1:TrcRecord.Sets(iSet).nVars]
      labels = [labels "," char(lineSplit(iCol))];
      iCol++;
    endfor
    TrcRecord.Sets(iSet).Params.labels = strsplit(labels(2:end), ",");
  endfor
  
  lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
  iCol = 1;
  for iSet = [1:TrcRecord.nSets]
    units = "";
    for iVar = [1:TrcRecord.Sets(iSet).nVars]
      units = [units "," char(lineSplit(iCol))];
      iCol++;
    endfor
    TrcRecord.Sets(iSet).Params.units = strsplit(units(2:end), ",");
  endfor
  
  iPoint = 1;
  while (!feof(fCsv))
    lineSplit = strsplit(fgetl(fCsv),",","collapsedelimiters",false);
    iCol = 1;
    for iSet = [1:TrcRecord.nSets]
      vals = [];
      for iVar = [1:TrcRecord.Sets(iSet).nVars]
        if (!strcmp(lineSplit(iCol), ""))
          vals = [vals str2double(lineSplit(iCol))];
        endif
        iCol++;
      endfor
      if (length(vals) == TrcRecord.Sets(iSet).nVars)
        TrcRecord.Sets(iSet).values(iPoint,:) = vals;
      endif
    endfor    
    iPoint++;
  endwhile

  fclose(fCsv);

  nPoints = [];
  for iSet = [1:TrcRecord.nSets]
    nPoints(iSet) = size(TrcRecord.Sets(iSet).values, 1);
    TrcRecord.Sets(iSet).nPoints = nPoints(iSet);
    TrcRecord.Sets(iSet).nVars = size(TrcRecord.Sets(iSet).values, 2);
  endfor
  TrcRecord.nPointsMax = max(nPoints);
  
endfunction
